# -*- encoding: utf-8 -*-

import re

from pymoji.utils import Singleton, ensure_unicode, get_package_version
from pymoji.resources.nature import NATURE_MOJI_RESOURCES
from pymoji.resources.objects import OBJECTS_MOJI_RESOURCES
from pymoji.resources.people import PEOPLE_MOJI_RESOURCES
from pymoji.resources.places import PLACES_MOJI_RESOURCES
from pymoji.resources.symbols import SYMBOLS_MOJI_RESOURCES

__all__ = ['PyMoji']
__version__ = get_package_version()


class PyMoji(object):

    __metaclass__ = Singleton

    def __init__(self):
        self.moji_resources = dict(
            NATURE_MOJI_RESOURCES.items() +
            OBJECTS_MOJI_RESOURCES.items() +
            PEOPLE_MOJI_RESOURCES.items() +
            PLACES_MOJI_RESOURCES.items() +
            SYMBOLS_MOJI_RESOURCES.items()
        )
        self.moji_resources_reversed = {message: code for code, message in self.moji_resources.items()}
        self.encode_r = re.compile(r'(%s)' % '|'.join(self.moji_resources.keys()))
        self.decode_r = re.compile(r'(%s)' % '|'.join([re.escape(message) for message in self.moji_resources_reversed.keys()]))

    def encode(self, text):
        return self.encode_r.sub(lambda m: self.moji_resources[m.group()], ensure_unicode(text))

    def decode(self, text):
        return self.decode_r.sub(lambda m: self.moji_resources_reversed[m.group()], ensure_unicode(text))



# -*- encoding: utf-8 -*-


import os.path
from pkg_resources import get_distribution, DistributionNotFound


class Singleton(type):

    _instances = {}

    def __call__(cls, *args, **kwargs):
        if cls not in cls._instances:
            cls._instances[cls] = super(Singleton, cls).__call__(*args, **kwargs)
        return cls._instances[cls]


def ensure_unicode(text):
    if isinstance(text, unicode):
        return text
    return text.decode('utf-8')


def get_package_version():
    try:
        _dist = get_distribution('pymoji')
        if not __file__.startswith(os.path.join(_dist.location, 'pymoji')):
            raise DistributionNotFound
    except DistributionNotFound:
        __version__ = 'Please install this project with setup.py'
    else:
        __version__ = _dist.version
    return __version__





# -*- coding: utf-8 -*-

from setuptools import setup, find_packages


with open('README.rst', 'rt') as f:
    long_description = f.read()


setup(
    name='pymoji',
    version='0.1.1',
    description='Converter between Emoji Unicode and Ascii Text.',
    author='mapix',
    author_email='mapix.me@gmail.com',
    url='https://github.com/mapix/pymoji',
    license='MIT',
    packages=find_packages(),
    install_requires=['distribute',],
    long_description=long_description,
)
